==> haskell-th-orphans-0.13.7-17-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-th-orphans.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: th-orphans
version: 0.13.7
id: th-orphans-0.13.7-EKwjXscRv8SED56HtE2rkn
key: th-orphans-0.13.7-EKwjXscRv8SED56HtE2rkn
license: BSD-3-Clause
copyright: (c) Matt Morrow
maintainer: Michael Sloan <mgsloan at gmail>
author: Matt Morrow
stability: experimental
synopsis: Orphan instances for TH datatypes
description:
    Orphan instances for TH datatypes.  In particular, instances
    for Ord and Lift, as well as a few missing Show / Eq.  These
    instances used to live in haskell-src-meta, and that'\''s where
    the version number started.
category: Template Haskell
abi: 99e663d62cea02c0a32059c5a834f886
exposed: True
exposed-modules:
    Language.Haskell.TH.Instances
import-dirs: /usr/lib/ghc-8.6.5/site-local/th-orphans-0.13.7
library-dirs: /usr/lib/ghc-8.6.5/site-local/th-orphans-0.13.7
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/th-orphans-0.13.7
hs-libraries: HSth-orphans-0.13.7-EKwjXscRv8SED56HtE2rkn
depends:
    base-4.12.0.0 mtl-2.2.2 template-haskell-2.14.0.0
    th-lift-0.7.11-hZJVZ2zmXw59mRAYP9RXW
    th-lift-instances-0.1.11-KEK8nmCaHnrC13tbi99jb2
    th-reify-many-0.1.9-AO2I3KZjoiS9IDtUI7zilG
haddock-interfaces: /usr/share/doc/haskell-th-orphans/html/th-orphans.haddock
haddock-html: /usr/share/doc/haskell-th-orphans/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-th-orphans-0.13.7-18-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-th-orphans.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: th-orphans
version: 0.13.7
id: th-orphans-0.13.7-Er82mdJkzmAHpP4VUC6L3f
key: th-orphans-0.13.7-Er82mdJkzmAHpP4VUC6L3f
license: BSD-3-Clause
copyright: (c) Matt Morrow
maintainer: Michael Sloan <mgsloan at gmail>
author: Matt Morrow
stability: experimental
synopsis: Orphan instances for TH datatypes
description:
    Orphan instances for TH datatypes.  In particular, instances
    for Ord and Lift, as well as a few missing Show / Eq.  These
    instances used to live in haskell-src-meta, and that'\''s where
    the version number started.
category: Template Haskell
abi: e8f39d23ecb697e3114779bd04614197
exposed: True
exposed-modules:
    Language.Haskell.TH.Instances
import-dirs: /usr/lib/ghc-8.6.5/site-local/th-orphans-0.13.7
library-dirs: /usr/lib/ghc-8.6.5/site-local/th-orphans-0.13.7
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/th-orphans-0.13.7
hs-libraries: HSth-orphans-0.13.7-Er82mdJkzmAHpP4VUC6L3f
depends:
    base-4.12.0.0 mtl-2.2.2 template-haskell-2.14.0.0
    th-lift-0.7.11-hZJVZ2zmXw59mRAYP9RXW
    th-lift-instances-0.1.11-KEK8nmCaHnrC13tbi99jb2
    th-reify-many-0.1.9-AO2I3KZjoiS9IDtUI7zilG
haddock-interfaces: /usr/share/doc/haskell-th-orphans/html/th-orphans.haddock
haddock-html: /usr/share/doc/haskell-th-orphans/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
